Revert "Revert adoption of CUDA indexing in general - this can only work with later versions of the compiler, just like module based dispatch, and thus must be guarded against usage in earlier (e.g. 1.6) versions."

This reverts commit d2fd1f5


[ROCm/hip commit: fbaf729f88]
Этот коммит содержится в:
Alex Voicu
2017-11-29 21:36:29 +00:00
родитель c58a083e96
Коммит fcc42f035e
62 изменённых файлов: 152 добавлений и 152 удалений
+2 -2
Просмотреть файл
@@ -16,13 +16,13 @@
__global__ void cpy(hipLaunchParm lp, uint32_t *Out, uint32_t *In)
{
int tx = threadIdx.x;
int tx = hipThreadIdx_x;
memcpy(Out + tx, In + tx, sizeof(uint32_t));
}
__global__ void set(hipLaunchParm lp, uint32_t *ptr, uint8_t val, size_t size)
{
int tx = threadIdx.x;
int tx = hipThreadIdx_x;
memset(ptr + tx, val, sizeof(uint32_t));
}